<img src=".figs/LANCET EUROPE LOGO.svg" alt="drawing" width="270"/>  

<div align="justify">

# Indicator 1.3.5: Leishmaniasis (v2024)

## Introduction

The leishmaniases are climate-sensitive zoonotic diseases caused by *Leishmania* protozoan parasites and transmitted by the bites of infectious female sand flies (Diptera: Psychodidae: *Phlebotominae*). Endemic in 99 countries or territories, leishmaniasis disproportionately affects the poorest and marginalised communities, with an estimated 700,000 to 1 million (underreported) new human cases globally every year. Furthermore, leishmaniasis is considered a climate-sensitive infectious disease, as sand fly species distributions tend to be restricted to warmer areas, although optimum temperature and humidity conditions for sand fly activity vary substantially between species and regions, influencing sand fly metabolism, and the development and survival of the sand fly life stages.

The **Leishmaniasis risk** indicator, published in the Lancet Countdown [Global](https://lancetcountdown.org/) report, tracks risk for leishmaniasis based one climatic suitablility and socio-economic factors, starting in 1951 until near present time.

## Methods
A machine learning approach was used, building on the work of [Carvalho et al. (2024)](https://www.sciencedirect.com/science/article/pii/S2666776224001388) to predict the risk for visceral and cutaneous leishmaniasis according to climatic suitability and socio-economic risks, in the baseline period 1960-2012 and subsequently generated annual predictions for 1951-1959 and 2013-2024. The model was trained on a variety of climatic and socioeconomic features against a binary leishmaniasis absence/presence outcome variable.

#### Data sources

| Variable | Source | Spatial Resolution | Temporal range used | 
| ------ | ------ | ------ | ------ |
| Monthly 2 meter dew point temperature | [ERA5 (monthly)](https://cds.climate.copernicus.eu/cdsapp#!/dataset/reanalysis-era5-land-monthly-means?tab=overview) | 0.1º x 0.1º | Jan 1950 - Dec 2020 |
| Monthly 2 meter temperature | [ERA5 (monthly)](https://cds.climate.copernicus.eu/cdsapp#!/dataset/reanalysis-era5-land-monthly-means?tab=overview) | 0.1º x 0.1º | Jan 1950 - Dec 2020 |
| Monthly accumulated precipitation | [ERA5 (monthly)](https://cds.climate.copernicus.eu/cdsapp#!/dataset/reanalysis-era5-land-monthly-means?tab=overview) | 0.1º x 0.1º | Jan 1950 - Dec 2020 |
| Land cover | [CORINE](https://land.copernicus.eu/pan-european/corine-land-cover/clc2018) | 100m | 2018 |
| Altitude | [JISAO](http://research.jisao.washington.edu/data_sets/elevation/) | 0.5º x 0.5º | - |


## How to read this folder

* [01_ComputeClimateSuitability](01_ComputeClimateSuitability.R): 
    * Import and transform climate variables
    * Compute relative humidity
    * Compute and save climate suitability
* [02_ComputeEnvironmentalSuitability](02_ComputeEnvironmentalSuitability.R):
    * Import and reclassify land cover classes
    * Save environmental suitability
* [03_ComputeNumberOfMonths](03_ComputeNumberOfMonths.R):
    * Combine climate and environmental suitability
    * Compute number of months per year with climate and environmental suitability at different levels
* [04_StratifyByElevation](04_StratifyByElevation.R):
    * Import altitude data
    * Compute number of suitable months stratified by elevation
* [05_ComputeRelativeDifferences](05_ComputeRelativeDifferences.R): 
    * Compute relative change between 1951-1985 and 1986-2020
* [06_CreatePlots](05_CreatePlots.R):
    * Create plots included in the report

## Authors
##### - Gina E C Charnley, PhD [(ORCID)](https://orcid.org/0000-0003-2087-7822)
##### - Adria San Jose Plana, PhD 
##### - Carla Maia, PhD 
##### - Orin Courtenay, PhD
##### - Prof. Jan Semenza
##### - Prof. Rachel Lowe [(ORCID)](https://orcid.org/0000-0003-3939-7343)

##### Contact: georgina.charnley@bsc.es
